@@ -49,7 +49,7 @@ Gfox <- function(X, Y, r=NULL, breaks=NULL,
 # censoring indicators
   d <- (dist <= bdry)
 #  observed distances
-  o <- pmin(dist, bdry)
+  o <- pmin.int(dist, bdry)
 # calculate estimates
   Z <- censtimeCDFest(o, bdry, d, breaks,
                       KM=corx$km,
